@@ -42,6 +42,8 @@ def login(request):
     client_secret = settings.IDENTITY_CLIENT_SECRET
 
     token_url = urljoin(settings.IDENTITY_HOST, "/o/token/")
+
+    # First attempt: Use the Authorization header (Basic Auth)
     reply = requests.post(
         token_url,
         data={
@@ -51,14 +53,29 @@ def login(request):
         },
         auth=(client_id, client_secret),
     )
+
+    # Fallback: If Authorization header fails, use client_id and client_secret in the body
+    if reply.status_code == 401:
+        reply = requests.post(
+            token_url,
+            data={
+                "grant_type": "authorization_code",
+                "code": auth_code,
+                "redirect_uri": auth_redirect_url,
+                "client_id": client_id,
+                "client_secret": client_secret,
+            },
+        )
+
     try:
         reply.raise_for_status()
     except requests.exceptions.HTTPError as e:
         message = (
-            "Auth request failed with status %s: %s; %s",
-            e.response.status_code,
-            e.response.content,
-            auth_redirect_url,
+            "Token request failed. "
+            f"Status: {e.response.status_code}, "
+            f"Auth Redirect URL: {auth_redirect_url}, "
+            f"Reason: {e.response.reason}, "
+            f"Error Details: {e.response.text[:500]}"
         )
         return HttpResponse(f"Unauthorized: {message}", status=401)
 
@@ -73,10 +90,10 @@ def login(request):
         reply.raise_for_status()
     except requests.exceptions.HTTPError as e:
         message = (
-            "Auth request failed with status %s: %s; %s",
-            e.response.status_code,
-            e.response.content,
-            tokens["access_token"],
+            "Introspection failed. "
+            f"Status: {e.response.status_code}, "
+            f"Reason: {e.response.reason}, "
+            f"Error Details: {e.response.text[:500]}..."
         )
         return HttpResponse(f"Unauthorized: {message}", status=401)
 
